@@ -97,34 +97,47 @@ sites.put2 <- function(G, data, id=NULL, dims, lname="", all.sites=FALSE,
 	dnames <- colnames(data)
 	data.attr <- as.data.frame(data[, -drops])
 	da.ncol <- ncol(data.attr)
-	dnames <- dnames[-drops]
-
-	xnumeric <- which(unlist(lapply(data.attr, is.numeric)))
-	xother <- which(unlist(lapply(data.attr, function(x) !is.numeric(x))))
-	ndbls <- length(xnumeric)
 	dblnames <- NULL
 	dbl.mat <- NULL
-	if (length(xnumeric) > 0) {
-		if (da.ncol == 1) {
-			dbl.mat <- matrix(data.attr[,1], ncol=1, nrow=n)
-		} else {
-			dbl.mat <- as.matrix(data.attr[, xnumeric])
-		}
-		dblnames <- dnames[xnumeric]
-		if (is.integer(dbl.mat)) dbl.mat <- as.numeric(dbl.mat)
-	}
-
-	nstrs <- length(xother)
 	strnames <- NULL
 	str.mat <- NULL
-	if (nstrs > 0) {
-		if (da.ncol == 1) {
-			str.mat <- matrix(as.character(data.attr[,1]), 
-				ncol=1, nrow=n)
-		} else {
-			str.mat <- as.matrix(data.attr[, xother])
+	if (da.ncol == 0) {
+		xnumeric <- NULL
+		xother <- NULL
+		ndbls <- 0
+		nstrs <- 0
+		dblnames <- NULL
+		strnames <- NULL
+		warning("No attributes transferred, only dimensions")
+	} else {
+		dnames <- dnames[-drops]
+
+		xnumeric <- which(unlist(lapply(data.attr, is.numeric)))
+		xother <- which(unlist(lapply(data.attr,
+			function(x) !is.numeric(x))))
+		ndbls <- length(xnumeric)
+		
+		if (length(xnumeric) > 0) {
+			if (da.ncol == 1) {
+				dbl.mat <- matrix(data.attr[,1], ncol=1, nrow=n)
+			} else {
+				dbl.mat <- as.matrix(data.attr[, xnumeric])
+			}
+			dblnames <- dnames[xnumeric]
+			if (is.integer(dbl.mat)) dbl.mat <- as.numeric(dbl.mat)
+		}
+
+		nstrs <- length(xother)
+	
+		if (nstrs > 0) {
+			if (da.ncol == 1) {
+				str.mat <- matrix(as.character(data.attr[,1]), 
+					ncol=1, nrow=n)
+			} else {
+				str.mat <- as.matrix(data.attr[, xother])
+			}
+			strnames <- dnames[xother]
 		}
-		strnames <- dnames[xother]
 	}
 
 	labs <- paste(c(dimsnames, idname, dblnames, strnames), collapse=" ")
